/*
 * Copyright 2006-2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.objenesis.tck.features;

import org.objenesis.Objenesis;

/**
 * A feature is a behavior that we expect from an instantiator. For example, we expect a serializing instantiator
 * to call the no-arg constructor of the first none-serializable parent class.
 *
 * @author Henri Tremblay
 */
public interface Feature {

   boolean isCompliant(Objenesis objenesis);
}
